<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LXQtWorldClock</name>
    <message>
        <location filename="../lxqtworldclock.cpp" line="245"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;yyyy MMM ddd, d&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfiguration</name>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
        <source>World Clock Settings</source>
        <translation>세계 시계 설정</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
        <source>Display &amp;format</source>
        <translation>표시 형식(&amp;F)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="30"/>
        <source>&amp;Time</source>
        <translation>시간(&amp;T)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="39"/>
        <source>F&amp;ormat:</source>
        <translation>형식(&amp;O):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="50"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="176"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="272"/>
        <source>Short</source>
        <translation>짧은</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="55"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="181"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="277"/>
        <source>Long</source>
        <translation>긴</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="60"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="287"/>
        <source>Custom</source>
        <translation>사용자 지정</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="89"/>
        <source>Sho&amp;w seconds</source>
        <translation>초 표시(&amp;W)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="96"/>
        <source>Pad &amp;hour with zero</source>
        <translation>패드 시간 0으로(&amp;H)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="116"/>
        <source>T&amp;ime zone</source>
        <translation>시간대(&amp;I)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="128"/>
        <source>&amp;Position:</source>
        <translation>위치(&amp;P):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="138"/>
        <source>For&amp;mat:</source>
        <translation>형식(&amp;M):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="149"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="238"/>
        <source>Below</source>
        <translation>아래</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="154"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="243"/>
        <source>Above</source>
        <translation>위</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="159"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="248"/>
        <source>Before</source>
        <translation>전</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="164"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="253"/>
        <source>After</source>
        <translation>후</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="186"/>
        <source>Offset from UTC</source>
        <translation>UTC에서 오프셋</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="191"/>
        <source>Abbreviation</source>
        <translation>약어</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="431"/>
        <source>IANA id</source>
        <translation>IANA id</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
        <source>Custom name</source>
        <translation>사용자 지정 이름</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="103"/>
        <source>&amp;Use 12-hour format</source>
        <translation>12시간 형식 사용(&amp;U)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="196"/>
        <source>Location identifier</source>
        <translation>위치 식별자</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="212"/>
        <source>&amp;Date</source>
        <translation>날짜(&amp;D)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="227"/>
        <source>Po&amp;sition:</source>
        <translation>위치(&amp;S):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="261"/>
        <source>Fo&amp;rmat:</source>
        <translation>형식(&amp;R):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="282"/>
        <source>ISO 8601</source>
        <translation>ISO 8601</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="316"/>
        <source>Show &amp;year</source>
        <translation>연도 표시(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="323"/>
        <source>Show day of wee&amp;k</source>
        <translation>요일 표시(&amp;K)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="330"/>
        <source>Pad d&amp;ay with zero</source>
        <translation>앞에 0이 있는 날(&amp;A)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="337"/>
        <source>&amp;Long month and day of week names</source>
        <translation>긴 월 및 요일 이름(&amp;L)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="350"/>
        <source>Ad&amp;vanced manual format</source>
        <translation>고급 수동 형식(&amp;V)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="377"/>
        <source>&amp;Customize ...</source>
        <translation>사용자 정의(&amp;C) ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="403"/>
        <source>Time &amp;zones</source>
        <translation>시간대(&amp;Z)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="446"/>
        <source>&amp;Add ...</source>
        <translation>추가하기(&amp;A) ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="456"/>
        <source>&amp;Remove</source>
        <translation>제거하기(&amp;R)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="466"/>
        <source>Set as &amp;default</source>
        <translation>기본값으로 지정(&amp;D)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="476"/>
        <source>&amp;Edit custom name ...</source>
        <translation>사용자 지정 이름 편집하기(&amp;E) ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="486"/>
        <source>Move &amp;up</source>
        <translation>위로 이동(&amp;U)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="496"/>
        <source>Move do&amp;wn</source>
        <translation>아래로 이동(&amp;W)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="518"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Middle-click the clock to view the time and date for all configured timezones.</source>
        <translation>&lt;b&gt;참고:&lt;/b&gt; 시계를 마우스 가운데로 클릭하여 구성된 모든 시간대의 시간과 날짜를 확인합니다.</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="529"/>
        <source>&amp;General</source>
        <translation>일반(&amp;G)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>패널이 수직일 때 자동 회전(&amp;R)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
        <source>Show &amp;week numbers in popup calendar</source>
        <translation>팝업 달력에 주 번호 표시(&amp;W)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="555"/>
        <source>S&amp;how tooltip</source>
        <translation>툴팁 표시(&amp;H)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="106"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;yyyy MMM ddd, d&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="584"/>
        <source>Input custom time zone name</source>
        <translation>사용자 지정 시간대 이름 입력</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationManualFormat</name>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
        <source>World Clock Manual Format Configuration</source>
        <translation>세계 시계 수동 형식 구성</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
        <source>&lt;h1&gt;Custom Date/Time Format Syntax&lt;/h1&gt;
&lt;p&gt;A date pattern is a string of characters, where specific strings of characters are replaced with date and time data from a calendar when formatting or used to generate data for a calendar when parsing.&lt;/p&gt;
&lt;p&gt;The Date Field Symbol Table below contains the characters used in patterns to show the appropriate formats for a given locale, such as yyyy for the year. Characters may be used multiple times. For example, if y is used for the year, &apos;yy&apos; might produce &apos;99&apos;, whereas &apos;yyyy&apos; produces &apos;1999&apos;. For most numerical fields, the number of characters specifies the field width. For example, if h is the hour, &apos;h&apos; might produce &apos;5&apos;, but &apos;hh&apos; produces &apos;05&apos;. For some characters, the count specifies whether an abbreviated or full form should be used, but may have other choices, as given below.&lt;/p&gt;
&lt;p&gt;Two single quotes represents a literal single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). Otherwise all ASCII letter from a to z and A to Z are reserved as syntax characters, and require quoting if they are to represent literal characters. In addition, certain ASCII punctuation characters may become variable in the future (eg &quot;:&quot; being interpreted as the time separator and &apos;/&apos; as a date separator, and replaced by respective locale-sensitive characters in display).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Meaning&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;the day as number without a leading zero (1 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;the day as number with a leading zero (01 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;the month as number without a leading zero (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;the month as number with a leading zero (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;the year as two digit number (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;the year as four digit number&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;the minute without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;the offset from UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;the timezone IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;the timezone abbreviation&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;the timezone short display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;the timezone long display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
</source>
        <translation>&lt;h1&gt;사용자 지정 날짜/시간 형식 구문&lt;/h1&gt;
&lt;p&gt;날짜 패턴은 형식을 지정할 때 특정 문자열이 달력의 날짜 및 시간 데이터로 대체되거나 구문 분석할 때 달력에 대한 데이터를 생성하는 데 사용되는 문자열입니다.&lt;/p&gt;
&lt;p&gt;아래의 날짜 필드 기호 테이블에는 연도의 yyyy와 같이 주어진 로케일에 적절한 형식을 표시하기 위해 패턴에 사용되는 문자가 포함되어 있습니다. 문자는 여러 번 사용할 수 있습니다. 예를 들어, y가 연도에 사용되는 경우 &apos;yy&apos;는 &apos;99&apos;를 생성하고 &apos;yyyy&apos;는 &apos;1999&apos;를 생성할 수 있습니다. 대부분의 숫자 필드의 경우 문자 수가 필드 너비를 지정합니다. 예를 들어, h가 시간인 경우 &apos;h&apos;는 &apos;5&apos;를 생성하지만 &apos;hh&apos;는 &apos;05&apos;를 생성합니다. 일부 문자의 경우 개수는 약어 또는 전체 형식을 사용해야 하는지 여부를 지정하지만 아래와 같이 다른 선택이 있을 수 있습니다.&lt;/p&gt;
&lt;p&gt;작은 따옴표 두 개는 작은 따옴표 내부 또는 외부에 있는 리터럴 작은 따옴표를 나타냅니다. 작은따옴표 안에 있는 텍스트는 어떤 식으로든 해석되지 않습니다(인접한 두 개의 작은따옴표 제외). 그렇지 않으면 a에서 z 및 A에서 Z까지의 모든 ASCII 문자가 구문 문자로 예약되어 있으며 리터럴 문자를 나타내려면 따옴표가 필요합니다. 또한 특정 ASCII 문장 부호 문자는 나중에 변경될 수 있습니다(예: &quot;:&quot;는 시간 구분 기호로, &apos;/&apos;는 날짜 구분 기호로 해석되며 디스플레이에서 각각의 로케일 구분 문자로 대체됨).&lt;br /&gt;&lt; /p&gt;
&lt;테이블 테두리=&quot;1&quot; 너비=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;코드&lt;/th&gt;&lt;th&gt;의미&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;앞에 0이 없는 숫자(1에서 31까지)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;앞에 0이 있는 숫자로 된 요일(01에서 31까지)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;지역화된 요일의 축약형(예: &apos;월&apos;에서 &apos;일&apos;까지).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;긴 현지화된 요일 이름(예: &apos;월요일&apos;에서 &apos;일요일&apos;까지).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;앞에 0이 없는 숫자로 된 월(1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;앞에 0이 있는 숫자로 된 월(01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;현지화된 약식 월 이름(예: &apos;Jan&apos;에서 &apos;Dec&apos;까지).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;긴 현지화된 월 이름(예: &apos;1월&apos;에서 &apos;12월&apos;까지).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;연도를 두 자리 숫자(00-99)로 표시&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;4자리 숫자로 된 연도&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;앞에 0이 없는 시간(AM/PM이 표시되는 경우 0에서 23 또는 1에서 12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;0이 앞에 오는 시간(AM/PM이 표시되는 경우 00에서 23 또는 01에서 12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;앞에 0이 없는 시간(0에서 23까지, AM/PM 표시가 있는 경우에도)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;앞에 0이 있는 시간(AM/PM 표시가 있는 경우에도 00에서 23까지)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;앞에 0이 없는 분(0 ~ 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;앞에 0이 있는 분(00 ~ 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;앞에 0이 없는 초(0 ~ 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;0이 앞에 오는 초(00 ~ 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;또는&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;AM/PM 디스플레이를 사용합니다. &lt;b&gt;A/AP&lt;/b&gt;는 &quot;AM&quot; 또는 &quot;PM&quot;으로 대체됩니다.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;또는&lt;/i&gt;&lt;/td&gt;&lt;td&gt;am/pm 디스플레이를 사용합니다. &lt;b&gt;a/ap&lt;/b&gt;은 &quot;am&quot; 또는 &quot;pm&quot;으로 대체됩니다.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;시간대(예: &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;UTC에서의 오프셋&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;시간대 IANA ID&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;시간대 약어&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;시간대 짧은 표시 이름&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;시간대 긴 표시 이름&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;시간대 사용자 정의 이름. 구성 창의 &apos;시간대&apos; 탭에서 변경할 수 있습니다.&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;참고:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;[&apos;a&apos;..&apos;z&apos;] 및 [&apos;A&apos;..&apos;Z&apos;] 범위에 없는 패턴의 모든 문자는 인용된 텍스트로 처리됩니다. 예를 들어, &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; 및 &apos;@&apos;와 같은 문자는 작은 따옴표로 묶이지 않아도 결과 시간 텍스트에 나타납니다. 작은 따옴표는 문자를 &apos;이스케이프&apos;하는 데 사용됩니다. 따옴표로 묶인 시퀀스의 내부 또는 외부에 있는 연속된 두 개의 작은따옴표는 &apos;실제&apos; 작은따옴표를 나타냅니다.&lt;/li&gt;&lt;li&gt;최소 업데이트 간격은 1초입니다. z 또는 zzz가 구성된 경우 시간이 밀리초 단위로 표시되지만 밀리초 단위로 업데이트되지 않습니다(큰 성능 저하 방지).&lt;/li&gt;&lt;ul&gt;
</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationTimeZones</name>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
        <source>World Clock Time Zones</source>
        <translation>세계 시계 시간대</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
        <source>Time zone</source>
        <translation>시간대</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="41"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="46"/>
        <source>Comment</source>
        <translation>주석</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="51"/>
        <source>Country</source>
        <translation>국가</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="117"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="120"/>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="128"/>
        <source>Other</source>
        <translation>기타</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="129"/>
        <source>Local timezone</source>
        <translation>현지 시간대</translation>
    </message>
</context>
</TS>
